<?php

namespace wcf\acp\form;
use wcf\data\style\Style;
use wcf\data\style\StyleList;
use wcf\form\AbstractForm;
use wcf\system\exception\UserInputException;
use wcf\system\language\I18nHandler;
use wcf\system\style\StyleHandler;
use wcf\system\WCF;
use wcf\util\ArrayUtil;
use wcf\util\FileUtil;
use wcf\util\StringUtil;

/**
 * Shows the field add form.
 *
 * @author	Florian Gail update mipu
 * @copyright	2004-2023 mipu <https://wbbsupport.de/>
 * @license	All rights reserved
 * @package	de.wbbsupport.wsc.acpCustomCSS
 * @category	Core
 */
class AcpCustomScssForm extends AbstractForm {
	/**
	 * @see	\wcf\page\AbstractPage::$activeMenuItem
	 */
	public $activeMenuItem = 'wcf.acp.menu.link.style.scssAcpCustomValues';
	
	/**
	 * @see	\wcf\page\AbstractPage::$neededPermissions
	 */
	public $neededPermissions = array('admin.style.canManageStyle');
	
	/**
	 * custom less
	 * @var	string
	 */
	public $acpCustomScss = '';
	
	/**
	 * @see	\wcf\form\IForm::readFormParameters()
	 */
	public function readFormParameters() {
		parent::readFormParameters();
		
		if (isset($_POST['individualScss'])) $this->acpCustomScss = StringUtil::trim($_POST['individualScss']);
	}
	
	/**
	 * @see	\wcf\form\IForm::save()
	 */
	public function save() {
		parent::save();
		
		$file = FileUtil::getRealPath(WCF_DIR) . 'acp/style/acpCustom_style.css';
		
		$string = '';
		
		if (empty($this->acpCustomScss)) {
		$string = '// DO NOT EDIT!
';
		}
		
		$string .= $this->acpCustomScss;
		
		file_put_contents($file, $string);
		
		$styleList = new StyleList();
		$styleList->readObjects();
		
		foreach ($styleList->getObjects() as $style) {
			StyleHandler::getInstance()->resetStylesheet($style);
		}
		
		$this->saved();
		
		// show success
		WCF::getTPL()->assign(array(
			'success' => true
		));
	}
	
	/**
	 * @see	\wcf\form\IForm::readData()
	 */
	public function readData() {
		parent::readData();
		
		$file = FileUtil::getRealPath(WCF_DIR) . 'acp/style/acpCustom_style.css';
		
		if (file_exists($file)) {
			$this->acpCustomScss = file_get_contents($file);
		}
	}
	
	/**
	 * @see	\wcf\page\IPage::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		WCF::getTPL()->assign(array(
			'individualScss' => $this->acpCustomScss
		));
	}
}
